# THIS FILE IS GENERATED FROM setup.py in pagosonline
short_version = '0.5.1'
version = '0.5.1'
full_version = '0.5.1'
git_revision = '79a521ea0896938418094a90e9e9e2dfb505be90'
release = True

if not release:
    version = full_version
